@@ -53,11 +53,16 @@ def get_class(name):
     if 'data_analyzation_plugins' in cfg:
         basename = os.path.basename(cfg['data_analyzation_plugins'])
         modname = os.path.splitext(basename)[0]
-        usermodule = imp.load_source(modname, cfg['data_analyzation_plugins'])
-        clsmembers = inspect.getmembers(usermodule, inspect.isclass)
-        for string_name, act_class in clsmembers:
-            if string_name == name:
-                return act_class
+        if os.path.isfile(cfg['data_analyzation_plugins']):
+            usermodule = imp.load_source(modname,
+                                         cfg['data_analyzation_plugins'])
+            clsmembers = inspect.getmembers(usermodule, inspect.isclass)
+            for string_name, act_class in clsmembers:
+                if string_name == name:
+                    return act_class
+        else:
+            logging.warning("File '%s' does not exist. Adjust ~/.hwrtrc.",
+                            cfg['data_analyzation_plugins'])
 
     logging.debug("Unknown class '%s'.", name)
     return None
@@ -92,23 +97,23 @@ def prepare_file(filename):
 
 
 def sort_by_formula_id(raw_datasets):
-    """"The parameter ``raw_datasets`` has to be of the format
+    """The parameter ``raw_datasets`` has to be of the format
 
-    [{'is_in_testset': 0,
-      'formula_id': 31L,
-      'handwriting': HandwrittenData(raw_data_id=2953),
-      'formula_in_latex': 'A',
-      'id': 2953L},
-     {'is_in_testset': 0,
-      'formula_id': 31L,
-      'handwriting': HandwrittenData(raw_data_id=4037),
-      'formula_in_latex': 'A',
-      'id': 4037L},
-     {'is_in_testset': 0,
-      'formula_id': 31L,
-      'handwriting': HandwrittenData(raw_data_id=4056),
-      'formula_in_latex': 'A',
-      'id': 4056L}]
+        [{'is_in_testset': 0,
+          'formula_id': 31L,
+          'handwriting': HandwrittenData(raw_data_id=2953),
+          'formula_in_latex': 'A',
+          'id': 2953L},
+         {'is_in_testset': 0,
+          'formula_id': 31L,
+          'handwriting': HandwrittenData(raw_data_id=4037),
+          'formula_in_latex': 'A',
+          'id': 4037L},
+         {'is_in_testset': 0,
+          'formula_id': 31L,
+          'handwriting': HandwrittenData(raw_data_id=4056),
+          'formula_in_latex': 'A',
+          'id': 4056L}]
     """
     by_formula_id = defaultdict(list)
     for el in raw_datasets:
